@@ -96,7 +96,7 @@ module Data.Ini.Config
 , listWithSeparator
 ) where
 
-import           Control.Applicative (Applicative(..), Alternative(..))
+import           Control.Applicative (Alternative(..))
 import           Control.Monad.Trans.Except
 import           Data.Ini.Config.Raw
 import           Data.Sequence (Seq)
